@@ -3,10 +3,10 @@ import unittest
 import os.path
 import sys
 import numpy as np
+import logging
 from gzip import open as gzip_open
 from sklearn.feature_extraction.text import CountVectorizer
-from datetime import datetime as dt
-import logging
+import time
 
 sys.path.append(os.path.abspath(os.path.join(os.path.dirname(__file__), '..')))
 LOGGER = logging.getLogger(__name__)
@@ -19,20 +19,19 @@ class TestBTM(unittest.TestCase):
         with gzip_open('dataset/SearchSnippets.txt.gz', 'rb') as file:
             texts = file.readlines()
 
-        vec = CountVectorizer(lowercase=False)
-        X = vec.fit_transform(texts)
-
-        vocab = np.array(vec.get_feature_names())
-        biterms = btm.util.biterms(X)
+        X, vocab = btm.util.get_vectorized_docs(texts)
+        biterms = btm.util.get_biterms(X)
 
         LOGGER.info('Modeling started')
-        model = btm.BTM(8, vocab.size, alpha=50/8, beta=0.01, L=0.5)
+        model = btm.BTM(X, T=8, W=vocab.size, M=20, alpha=50/8, beta=0.01, L=0.5)
+        # t1 = time.time()
         model.fit(biterms, iterations=10)
+        # t2 = time.time()
+        # LOGGER.info(t2 - t1)
         LOGGER.info('Modeling finished')
 
         self.assertIsInstance(model.phi_, np.ndarray)
         self.assertTupleEqual(model.phi_.shape, (vocab.size, 8))
-
         P_zd = model.transform(biterms)
 
         LOGGER.info('Perplexity started')
@@ -44,8 +43,9 @@ class TestBTM(unittest.TestCase):
         LOGGER.info('Coherence started')
         coherence = btm.metrics.coherence(model.phi_, X, M=20)
         self.assertIsInstance(coherence, np.ndarray)
-        self.assertGreater(len(coherence), 0.)
+        self.assertGreater(coherence.shape[0], 0)
         LOGGER.info('Coherence finished')
 
+
 if __name__ == '__main__':
     unittest.main()
